@@ -26,6 +26,7 @@ from typing import (
 
 from apischema.aliases import Aliaser
 from apischema.cache import cache
+from apischema.constraints import Constraints, merge_constraints
 from apischema.conversions.conversions import AnyConversion, DefaultConversion
 from apischema.conversions.converters import ValueErrorCatcher
 from apischema.conversions.visitor import (
@@ -71,6 +72,7 @@ from apischema.deserialization.methods import (
     OptionalMethod,
     PatternField,
     RawConstructor,
+    RawConstructorCopy,
     RecMethod,
     SetMethod,
     SimpleObjectMethod,
@@ -96,14 +98,12 @@ from apischema.objects.fields import FieldKind
 from apischema.objects.visitor import DeserializationObjectVisitor
 from apischema.recursion import RecursiveConversionsVisitor
 from apischema.schemas import Schema, get_schema
-from apischema.schemas.constraints import Constraints, merge_constraints
 from apischema.types import PRIMITIVE_TYPES, AnyType, NoneType
 from apischema.typing import get_args, get_origin, is_type, is_typed_dict, is_union
 from apischema.utils import (
     CollectionOrPredicate,
     Lazy,
     as_predicate,
-    deprecate_kwargs,
     get_origin_or_type,
     literal_values,
     opt_or,
@@ -155,6 +155,26 @@ def check_only(method: DeserializationMethod) -> bool:
     )
 
 
+def is_raw_dataclass(cls: type) -> bool:
+    return (
+        dataclasses.is_dataclass(cls)
+        and type(cls) == type  # no metaclass
+        and "__slots__" not in cls.__dict__
+        and not hasattr(cls, "__post_init__")
+        and all(f.init for f in dataclasses.fields(cls))
+        and cls.__new__ is object.__new__
+        and (
+            cls.__setattr__ is object.__setattr__
+            or getattr(cls, dataclasses._PARAMS).frozen  # type: ignore
+        )
+        and (
+            list(inspect.signature(cls.__init__, follow_wrapped=False).parameters)  # type: ignore
+            == ["__dataclass_self__" if "self" in dataclasses.fields(cls) else "self"]
+            + [f.name for f in dataclasses.fields(cls)]
+        )
+    )
+
+
 @dataclasses.dataclass(frozen=True)
 class DeserializationMethodFactory:
     factory: Factory
@@ -176,7 +196,7 @@ class DeserializationMethodFactory:
     # private intermediate method instead of decorated property because of mypy
     @lru_cache()
     def _method(self) -> DeserializationMethod:
-        return self.factory(self.constraints, self.validators)  # type: ignore
+        return self.factory(self.constraints, self.validators)
 
     @property
     def method(self) -> DeserializationMethod:
@@ -482,31 +502,12 @@ class DeserializationMethodVisitor(
                     )
             object_constraints = constraints_validators(constraints)[dict]
             all_alliases = set(alias_by_name.values())
-            constructor: Constructor
+            constructor: Optional[Constructor] = None
             if is_typed_dict(cls):
                 constructor = NoConstructor(cls)
             elif (
                 settings.deserialization.override_dataclass_constructors
-                and dataclasses.is_dataclass(cls)
-                and "__slots__" not in cls.__dict__
-                and not hasattr(cls, "__post_init__")
-                and all(f.init for f in dataclasses.fields(cls))
-                and cls.__new__ is object.__new__
-                and (
-                    cls.__setattr__ is object.__setattr__
-                    or getattr(cls, dataclasses._PARAMS).frozen  # type: ignore
-                )
-                and (
-                    list(
-                        inspect.signature(cls.__init__, follow_wrapped=False).parameters
-                    )
-                    == [
-                        "__dataclass_self__"
-                        if "self" in dataclasses.fields(cls)
-                        else "self"
-                    ]
-                    + [f.name for f in dataclasses.fields(cls)]
-                )
+                and is_raw_dataclass(cls)
             ):
                 constructor = FieldsConstructor(
                     cls,
@@ -522,8 +523,6 @@ class DeserializationMethodVisitor(
                         if f.default_factory is not dataclasses.MISSING
                     ),
                 )
-            else:
-                constructor = RawConstructor(cls)
             if (
                 not object_constraints
                 and not flattened_fields
@@ -546,7 +545,7 @@ class DeserializationMethodVisitor(
                 )
             ):
                 return SimpleObjectMethod(
-                    constructor,
+                    constructor or RawConstructorCopy(cls),
                     tuple(normal_fields),
                     all_alliases,
                     is_typed_dict(cls),
@@ -554,7 +553,7 @@ class DeserializationMethodVisitor(
                     settings.errors.unexpected_property,
                 )
             return ObjectMethod(
-                constructor,
+                constructor or RawConstructor(cls),
                 object_constraints,
                 tuple(normal_fields),
                 tuple(flattened_fields),
@@ -648,7 +647,11 @@ class DeserializationMethodVisitor(
                     if fact.cls is not NoneType
                 )
                 return OptionalMethod(value_method, self.coercer)
-            elif len(method_by_cls) == len(alt_factories):
+            elif len(method_by_cls) == len(alt_factories) and not any(
+                isinstance(x, CoercerMethod) for x in alt_methods
+            ):
+                # Coercion induces a different type in data than type to deserialize.
+                # Prefer UnionMethod in this case.
                 return UnionByTypeMethod(method_by_cls)
             else:
                 return UnionMethod(alt_methods)
@@ -866,13 +869,6 @@ def deserialize(
     ...
 
 
-@deprecate_kwargs(
-    {
-        "coercion": "coerce",
-        "conversions": "conversion",
-        "default_fallback": "fall_back_on_default",
-    }
-)
 def deserialize(
     type: AnyType,
     data: Any,
