@@ -66,7 +66,6 @@ from apischema.types import AnyType, OrderedDict, UndefinedType
 from apischema.typing import get_args, get_origin, is_typed_dict, is_union
 from apischema.utils import (
     context_setter,
-    deprecate_kwargs,
     get_origin_or_type,
     identity,
     is_hashable,
@@ -218,8 +217,8 @@ class SchemaBuilder(
         with context_setter(self):
             self._ignore_first_ref = True
             key = self.visit(key_type)
-        if key["type"] != JsonType.STRING:
-            raise ValueError("Mapping types must string-convertible key")
+        if "type" not in key or key["type"] != JsonType.STRING:
+            raise ValueError("Mapping types must have string-convertible keys")
         value = self.visit(value_type)
         if "pattern" in key:
             return json_schema(
@@ -619,7 +618,6 @@ def _schema(
     return result
 
 
-@deprecate_kwargs({"conversions": "conversion"})
 def deserialization_schema(
     tp: AnyType,
     *,
@@ -650,7 +648,6 @@ def deserialization_schema(
     )
 
 
-@deprecate_kwargs({"conversions": "conversion"})
 def serialization_schema(
     tp: AnyType,
     *,
