@@ -2,7 +2,6 @@ import collections.abc
 import inspect
 import re
 import sys
-import warnings
 from contextlib import contextmanager, suppress
 from dataclasses import dataclass, is_dataclass
 from enum import Enum
@@ -35,7 +34,7 @@ from typing import (
 
 from apischema.types import COLLECTION_TYPES, MAPPING_TYPES, PRIMITIVE_TYPES, AnyType
 from apischema.typing import (
-    _collect_type_vars,
+    _collect_parameters,
     generic_mro,
     get_args,
     get_origin,
@@ -139,7 +138,7 @@ def get_parameters(tp: AnyType) -> Iterable[TV]:
     if hasattr(tp, "__parameters__"):
         return tp.__parameters__
     elif hasattr(tp, "__orig_bases__"):
-        return _collect_type_vars(tp.__orig_bases__)
+        return _collect_parameters(tp.__orig_bases__)
     elif is_type_var(tp):
         return (tp,)
     else:
@@ -298,7 +297,7 @@ awaitable_origin = get_origin(Awaitable[Any])
 def is_async(func: Callable, types: Optional[Mapping[str, AnyType]] = None) -> bool:
     wrapped_func = func
     while hasattr(wrapped_func, "__wrapped__"):
-        wrapped_func = wrapped_func.__wrapped__  # type: ignore
+        wrapped_func = wrapped_func.__wrapped__
     if inspect.iscoroutinefunction(wrapped_func):
         return True
     if types is None:
@@ -380,34 +379,6 @@ else:
         return wrapped
 
 
-def deprecate_kwargs(
-    parameters_map: Mapping[str, Optional[str]]
-) -> Callable[[Func], Func]:
-    def decorator(func: Func) -> Func:
-        wrapped = func.__init__ if isinstance(func, type) else func  # type: ignore
-
-        def wrapper(*args, **kwargs):
-            for param, replacement in parameters_map.items():
-                if param in kwargs:
-                    instead = f", use '{replacement}' instead" if replacement else ""
-                    warnings.warn(
-                        f"{func.__name__} parameter '{param}' is deprecated{instead}",
-                        DeprecationWarning,
-                    )
-                    arg = kwargs.pop(param)
-                    if replacement:
-                        kwargs[replacement] = kwargs.get(replacement, arg)
-            return wrapped(*args, **kwargs)
-
-        if isinstance(func, type):
-            func.__init__ = wraps(func.__init__)(wrapper)  # type: ignore
-            return cast(Func, func)
-        else:
-            return cast(Func, wraps(func)(wrapper))
-
-    return decorator
-
-
 CollectionOrPredicate = Union[Collection[T], Callable[[T], bool]]
 
 
