@@ -1,4 +1,3 @@
-import warnings
 from dataclasses import (  # type: ignore
     _FIELD_CLASSVAR,
     _FIELDS,
@@ -72,7 +71,7 @@ def dataclass_types_and_fields(
             if INIT_VAR_METADATA not in metadata:
                 raise TypeError("Before 3.8, InitVar requires init_var metadata")
             init_field = (PREFIX, metadata[INIT_VAR_METADATA], ...)
-            tmp_cls = make_dataclass("Tmp", [init_field], bases=(cls,))  # type: ignore
+            tmp_cls = make_dataclass("Tmp", [init_field], bases=(cls,))
             types[field.name] = get_type_hints(tmp_cls, include_extras=True)[PREFIX]
             if has_type_vars(types[field.name]):
                 raise TypeError("Generic InitVar are not supported before 3.8")
@@ -87,14 +86,6 @@ class Unsupported(TypeError):
     def __init__(self, tp: AnyType):
         self.type = tp
 
-    @property
-    def cls(self) -> AnyType:
-        warnings.warn(
-            "Unsupported.cls is deprecated, use Unsupported.type instead",
-            DeprecationWarning,
-        )
-        return self.type
-
 
 Result = TypeVar("Result", covariant=True)
 
@@ -173,7 +164,7 @@ class Visitor(Generic[Result]):
                 return self.collection(origin, args[0])
             if origin in MAPPING_TYPES:
                 return self.mapping(origin, args[0], args[1])
-            if is_literal(tp):  # pragma: no cover py37+
+            if is_literal(tp):
                 return self.literal(args)
         if origin in PRIMITIVE_TYPES:
             return self.primitive(origin)
@@ -197,15 +188,14 @@ class Visitor(Generic[Result]):
             if is_named_tuple(origin):
                 if hasattr(origin, "__annotations__"):
                     types = resolve_type_hints(origin)
+                # TODO is __field_types for python 3.6 only?
                 elif hasattr(origin, "__field_types"):  # pragma: no cover
-                    types = origin.__field_types  # type: ignore
+                    types = origin.__field_types
                 else:  # pragma: no cover
                     types = OrderedDict((f, Any) for f in origin._fields)  # type: ignore  # noqa: E501
                 return self.named_tuple(
                     origin, types, origin._field_defaults  # type: ignore
                 )
-        if is_literal(origin):  # pragma: no cover py36
-            return self.literal(origin.__values__)
         if is_typed_dict(origin):
             return self.typed_dict(
                 origin, resolve_type_hints(origin), required_keys(origin)
